%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------------------------------------------------------------------------%
%      PROGRAM FOR A KALKULERE EKSERGI I ADSORPSJONSBEHOLDER              %
%      MED ADSORBENT Cu-BTC                                               %
%-------------------------------------------------------------------------%
% Indata                                                                  %
% T1 [K]                                                                  %
% P1 [KPa]                                                                %
% ng [Kmol/kg adsorbent]                                                  %
% nee [Kmol/kg adsorbent]                                                 %
% Utdata                                                                  %
% Eksergi [KJ]                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Exa] = Ex_CuBTC(T1,p1,ng,nee)

% Beholder og adsorbent data
e=0.37;         % Porsitet til Norit [-]
rhoa=485;       % Tetthet adsorbent Norit[kg/m3] 
v=9.853*10^-3;  % Volum innvedig i beholder [m3]
va=(1-e)*v;     % Volum adsorbent [m3]
ma=va*rhoa;     % Masse adsorbent i beholder [kg] 
Cph=13.8*2.016; % Varmekapasitet H2 [kJ/kmol K]
Csa=0.55;      % Varmekapasitet adsorbent[kJ/(kg*K)] 
Tenv=298;       % Omgivelsestemperatur [K]
penv=101;       % Omgivelsestrykk [kPa]
ech=236100;     % Kjemisk eksergi H2 [kJ/kmol]
R=8.314;        % Gasskonstant [kJ/(kmol*K)]

% Adsorbat data 
ntot=ng+nee;        % [Kmol/kg adsorbent]
nefin=1.2116e-004;  % [Kmol/kg adsorbent] 

% Eksergiutregning
h2a=zeros(10,1);
h2a(1)=ntot*(Cph-R)*(T1-Tenv); % [kJ/kg adsorbent] indre energiendring i H2 grunnet oppvarming
h2a(2)=Csa*(T1-Tenv); % [kJ/kg adsorbent] indre energiendring i adsorbentet grunnet oppvarming
h2a(4)=Himm_CuBTC(T1,p1)+nee*R*T1-Himm_CuBTC(Tenv,penv)-nefin*R*Tenv; % [kJ/kg adsorbent]
h2a(5)=ng*R*(penv*T1/p1-Tenv)+R*Tenv*(nefin-nee); % [kJ/kg adsorbent] Volumendring grunnet oppvarming
if p1==0
    h2a(5)=R*Tenv*(nefin-nee);
end
h2a(6)=-Tenv*ntot*(Cph*log(T1/Tenv)-R*log(p1/penv)); % [kJ/kg adsorbent] entropiendring for H2 grunnet oppvarming
h2a(7)=-Tenv*Csa*log(T1/Tenv); % [kJ/kg adsorbent] entropiendring for adsorbentet grunnet oppvarming
h2a(9)=-Tenv*(Simm_CuBTC(T1,p1)-Simm_CuBTC(Tenv,penv)); % [kJ/kg adsorbent] entropiendring grunnet immersjon
h2a(10)=ntot*ech; % [kJ/kg adsorbent] Eksergiendring fra kjemisk eksergi til H2

h2a=h2a*ma; % [kJ]
Exa=sum(h2a,1); % [kJ]

