%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------------------------------------------------------------------------%
%      PROGRAM FOR A KALKULERE IMMERSJONSENTALPI TIL Cu_BTC               %
%-------------------------------------------------------------------------%
% Indata                                                                  %
% T1 [K]                                                                  %
% P1 [KPa]                                                                %
% Utdata                                                                  %
% Himm [KJ/kg adsorbent]                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Himm] = Himm_CuBTC(T1,p1)

p1=p1/1000; % [MPa]

syms T
syms T0
syms deltaT0
syms p
syms n
syms n0
syms alfa
syms e;
syms B;
syms Ea;
syms R;
syms k0;
syms M
syms cmus
syms cmus0
syms k


q=cmus*(k*p)^(1/n)/(1+(k*p)^(1/n));
ne=q/(1000*M);
phi=-R*T*int(ne/p,p);

k=k0*exp(Ea/(R*T)-Ea/(R*T0));
cmus=cmus0*exp(deltaT0*(1 - T/T0));
n = 1/(1/n0 + alfa * (1 - T0/T));

phi =   -(R*T*cmus*n*log((k*p)^(1/n) + 1))/(1000); % basert p utregningen over

Himm=-T^2*diff((phi/T),T);

a(1)=13.28661107;
a(2)=13.66671544;
a(3)=3485.291712;
a(4)=1.612824008;
a(5)=0.486050748;
a(6)=0.710774622;

Himm=subs(Himm,M,2.016);
Himm=subs(Himm,R,8.314);
Himm=subs(Himm,cmus0,a(1));
Himm=subs(Himm,k0,a(2));
Himm=subs(Himm,Ea,a(3));
Himm=subs(Himm,n0,a(4));
Himm=subs(Himm,alfa,a(5));
Himm=subs(Himm,deltaT0,a(6));
Himm=subs(Himm,T0,77);

Himm=subs(subs(Himm,T,T1),p,p1);
if p1==0
    Himm=0;
end