%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------------------------------------------------------------------------%
%      PROGRAM FOR A KALKULERE IMMERSJONSENTROPI TIL NORIT R0.8           %
%-------------------------------------------------------------------------%
% Indata                                                                  %
% T1 [K]                                                                  %
% P1 [KPa]                                                                %
% Utdata                                                                  %
% Himm [KJ/kg adsorbent]                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Simm] = Simm_NORIT(T1,p1)

p1=p1/1000; % [MPa]

syms T
syms T0
syms deltaT0
syms p
syms n
syms n0
syms alfa
syms e;
syms B;
syms Ea;
syms R;
syms k0;
syms M
syms cmus
syms cmus0
syms k


q=cmus*(k*p)^(1/n)/(1+(k*p)^(1/n));
ne=q/(1000*M);
phi=-R*T*int(ne/p,p);

k=k0*exp(Ea/(R*T)-Ea/(R*T0));
cmus=cmus0*exp(deltaT0*(1 - T/T0));
n = 1/(1/n0 + alfa * (1 - T0/T));

phi =   -(R*T*cmus*n*log((k*p)^(1/n) + 1))/(1000); % basert p utregningen over

Simm=-diff(phi,T);

a(1)=15.35942037;
a(2)=12.89074434;
a(3)=3024.137773;
a(4)=1.223917594;
a(5)=0.197053678;
a(6)=0.584992676;

Simm=subs(Simm,M,2.016);
Simm=subs(Simm,R,8.314);
Simm=subs(Simm,cmus0,a(1));
Simm=subs(Simm,k0,a(2));
Simm=subs(Simm,Ea,a(3));
Simm=subs(Simm,n0,a(4));
Simm=subs(Simm,alfa,a(5));
Simm=subs(Simm,deltaT0,a(6));
Simm=subs(Simm,T0,77);

Simm=subs(subs(Simm,T,T1),p,p1);
if p1==0
    Simm=0;
end