%-------------------------------------------------------------------------%
% Transient eksergianalyse ved tapping av NORIT adsorpsjonsbeholder       %
% Basert p eksperimentelle data fra Aleksic (2010)                       %
%-------------------------------------------------------------------------%
% Indata:

Tenv=298;
penv=101;
Tut=298;
put=250;
T1=82.5;
p1=2000;
T2=68;
p2=250;

e=0.41;                     % Norit
e2=0.4;                     % Norit
rhoa=400;                   % tetthet adsorbent[kg/m3] - norit
rhom=8238;                  % tetthet rustfritt stl AISI 316  [kg/m3] 
v=9.853*10^-3;              % [m3]
vm=3.845*10^-3;             % volum til metallet i beholder [m3]
va=(1-e)*v;                 % volum adsorbent [m3]
vvoid=e*v+va*e2;            % volum void [m3]
ma=2.325;                   % NORIT [kg]
ca=0.15;                    % [kJ/(kg*K)]
ech=236100;                 % [kJ/kmol]
ExN2=21113;                 % [kJ/kmol]
cp=13.8*2.016;              % h2 [kJ/kmol K]
R=8.314;                    % [kJ/kmol K]
hfgN2=5588.8;               % [kJ/kmol]

ne1=sipnorit(T1,p1);        % [kmol/kg adsorbent]
ng1=(p1*vvoid/(R*T1))/ma;   % [Kmol/kg adsorbent]

ne2=sipnorit(T2,p2);        % [kmol/kg adsorbent]
ng2=p2*vvoid/(R*T2)/ma;     % [Kmol/kg adsorbent]

ntot2=(ne2+ng2);            % [Kmol/kg adsorbent]
ntot1=(ne1+ng1);            % [Kmol/kg adsorbent]
nut=ntot1-ntot2;            % [Kmol/kg adsorbent]

Ex1=Ex_NORIT(T1,p1,ng1,ne1);
Ex2=Ex_NORIT(T2,p2,ng2,ne2);
exf=cp*(Tut-Tenv)-Tenv*(cp*log(Tut/Tenv)-R*log(put/penv));

Q=ma*(ntot2*(cp*(T2-Tut)-R*T2)+ne2*R*T2+Himm_NORIT(T2,p2)-ntot1*(cp*(T1-Tut)-R*T1)-ne1*R*T1-Himm_NORIT(T1,p1)+ca*(T2-T1)); % [kJ]

Tb=(T1+T2)/2;
Exq=Q*(1-Tenv/Tb);
Exd=Ex1-Ex2-nut*ma*(exf+ech)+Q*(1-Tenv/Tb);
Exdp=Exd/(ech*ma*ntot1);          
pinn=(p1+p2)/2;
Exvd=ma*nut*Tenv*R*log(pinn/put);
Exvdp=Exvd/(ech*ma*ntot1);                 

% Skriver ut resultatene
Eksergi_i_tanken_ved_tappestart=Ex1/(ech*ma*ntot1)*100
Kjemiskeksergi_i_tanken_ved_tappestart=ntot1*ma*ech/(ech*ma*ntot1)*100
Total_eksergidestruksjon=Exdp*100  
Ekserginedbrytning_i_ventil=Exvdp*100               
Ekserginedbrytning_fra_temperaturgradienter=(Exdp-Exvdp)*100                     
Eksergioverforing_ved_varmeoverforing=Exq/(ech*ma*ntot1)*100
Eksergi_til_reaksjonscelle=ma*nut*(exf+ech)/(ech*ma*ntot1)*100     
Kjemiskeksergi_til_reaksjonscelle=ma*nut*(ech)/(ech*ma*ntot1)*100
Eksergi_i_tanken_ved_tappeslutt=Ex2/(ech*ma*ntot1)*100             
Kjemiskeksergi_i_tanken_ved_tappeslutt=ntot2*ma*ech/(ech*ma*ntot1)*100
ne2*ma
ng2*ma