%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------------------------------------------------------------------------%
% PROGRAM FOR A KALKULERE ADSORBERT HYDROGENMENGDE I Cu-BTC               %
% SOM FUNKSJON AV TRYKK OG TEMPERATUR                                     % 
%-------------------------------------------------------------------------%
% Indata                                                                  %
% T1 [K]                                                                  %
% P1 [kPa]                                                                %
% Utdata                                                                  %
% Adsorbert mengde [kmol/kg adsorbent]                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [sipcu] = sipcu(T,p)

p=p/1000; %MPa

% Diverse konstanter
cmus0=  13.28661107*10^-3; % [kmol/kg adsorbent]
b0=     13.66671544;
Q=      3485.291712;
n0=     1.612824008;
alfa=   0.486050748;
deltaT0=0.710774622;
R=      8.314;
T0=     77.000;
M=      2.016;
% Diverse variabler
n=1/(1/n0+alfa*(1-T0/T));
cmus=cmus0*exp(deltaT0*(1-T/T0));
b=b0*exp(Q/R*(1/T-1/T0));
% Lsning
sipcu=cmus*(b*p)^(1/n)/(1+(b*p)^(1/n)); % [kmol/kg adsorbent]